/*
					Simple HTML Forms Demo
						2006 Zac Stringham, a.k.a "Hiead"

		Simple HTML Forms is a demonstration of how to create your own forms for use
	in DreamSeeker. The forms will submit their values, and you can easily receive them!

	Pre-requisite would obviously be a fair understanding of HTML.
	Feel free to visit http://w3schools.com/html for some help as needed.

		Also, I apologize in advance for the massive commenting I've done. I just
	felt the need to explain some of the less-obvious interactions to people
	who haven't dabbled with this before.
____________________________

		client/Topic() will be the recipient of our HTML form. It is here that we will
	set up how we would like the information to be sent, and then in the form we
	know exactly what information is needed.

		For this demonstration, we will use an action value to determine what we
	would like to process. This action value would be sent to the href parameter as
	part of the text string, but more importantly to the href_list[] associated with
	its value.
*/
client/Topic(href, href_list[])
	if(href_list["action"])	// Checking for the existence isn't necessary
							// but will help in later debug output.

		// By using switch(), we will determine what the action is.
		switch(href_list["action"])

			if("say")

			// var/msg will be set to a value, with multiple modifications done afterwards
			// First, href_list["msg"] is evaluated to pull out the message.
			// It is then url_decode()-ed to remove any URL encoding.
			// Finally, it is html_encode()-ed to make it friendly in speech.

				var/msg = html_encode(url_decode(href_list["msg"]))
				if(msg)
					world << "<b>[mob.name]:</b> [msg]"

			if("set name")
				var/new_name = html_encode(url_decode(href_list["name"]))
				if(new_name)
					if(new_name != mob.name)
						mob.name = new_name
						src << "<tt>Name set to <b>[mob.name]</b>.</tt>"
					else
						src << "<tt>Name is already set to [mob.name].</tt>"

				else
					src << "<tt>No name was entered to set.</tt>"


/*
		Now that we've handled our basic "template" of how we'd like to receive the information,
	we can actually build the HTML page that sends it! Of course, I'll give you a little
	refresher on some BYOND-specific things you'll need to know to understand this.

	Firstly, we are sending data via HTML forms. The form tag will look something like this:
		<form name="formname" action="byond://" method="get">

		The name attribute isn't necessary, to be honest, but it can be helpful if you want to
	reference it later with something such as JavaScript.

		So, now that we've started our form, how does it get sent from the HTML page to
	DreamSeeker? It's simple, really. Form input tags send two pieces of data when you press
	the Submit button: A name and a value. the attributes that these belong to are obvious ones.

	For instance:
		<input type="text" name="msg" />

		When Submit is pressed, the value of this form element will be sent as
	"msg=", followed by the escaped value of whatever is inside the text box.
	This gets sent to client/Topic(), where the string will appear in the href parameter,
	and an associative list of names -> values will be stored in href_list[].

		However, not all information can be user-input, right? I mean, we must be able
	to set the form's action, that it may be well-received in Topic()! Fear not,
	this can easily be achieved using hidden form fields:

		<input type="hidden" name="action" value="say" />

		This input will not be seen by the user, but will be sent in the href to direct
	the Topic() proc as needed.

	And now it is time to build the HTML page! It will consist of three forms:
		-SayForm
			Sends a message, similar to a typical say() verb.

		-RenameForm
			Sets the mob's name to something else.

	And, without further ado:
*/

//	We'll go ahead and directly browse() the page in client/New(). Why not? :)
client/New()
	..()
	src << browse({"<html>
<head>
<title>Hiead's Simple HTML Form Demonstration</title>
<style type="text/css">
form
{
	background-color:#f0f8ff;
	color:#000010;
	border: 2px outset #81a1c6;
	padding: 4pt;
}
input
{
	background-color:#81a1c6;
	color:#fff;
	border: 1px inset #6181a6;
}
a
{
	color:#00f;
	text-decoration:none;
}
</style>
</head>

<body>

<form name="SayForm" action="byond://" method="get">
<p>
<input type="hidden" name="action" value="say" />

What would you like to say?<br />

<input type="text" name="msg" size="15" /> <input type="submit" value="Say It!" />
</p>
</form>

<hr />

<form name="RenameForm" action="byond://" method="get">
<p>
<input type="hidden" name="action" value="set name" />

Enter your new name:<br />

<input type="text" name="name" size="15" /> <input type="submit" value="Set Name" />
</p>
</form>

<p>When you finish playing with this...<br />
Study up on your <a href="http://www.w3schools.com/html">HTML</a>!</p>
</body>
</html>"})

//		You'll notice I went slightly out of my way in the style tags to make it more
//	visually friendly than a plain black/white window. This will not affect the form
//	communications at all.

//	And that's all there is to it! Good luck. 			~ Hiead